import React from "react";
import { InlineSingleDatePickerInput } from "./inline-single-date-picker-input";
import { PureComponent } from "react";
import { SingleDatePicker } from "./single-date-picker";
import { SingleDatePickerButtons } from "./single-date-picker-buttons";
import { SingleDatePickerCalendar } from "./single-date-picker-calendar";
import { bool, element, func, number, oneOf, oneOfType, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes"; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the props will not render properly in the docs.

const SINGLE_DATE_PICKER_PROP_TYPES = {
  /**
   * A controlled date value.
   */
  date: momentType,

  /**
   * The initial value of date.
   */
  defaultDate: momentType,

  /**
   * Called when the date is applied.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {Moment} date - Selected date.
   * @returns {void}
   */
  onDateChange: func.isRequired,

  /**
   * Called when the calendar open / close.
   * Called when the calendar open / close.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {boolean} isVisible - Indicate if the calendar is visible.
   * @returns {void}
   */
  onVisibilityChange: func,

  /**
   * Whether or not the calendar selected date(s) can be cleared.
   */
  allowClear: bool,

  /**
   * The minimum (inclusive) date available for selection.
   */
  minDate: momentType,

  /**
   * The maximum (inclusive) date available for selection.
   */
  maxDate: momentType,

  /**
   * An initial visible month displayed when the calendar open.
   */
  initialVisibleMonth: oneOfType([momentType, func]),

  /**
   * The number of months displayed simultaneously in the calendar.
   */
  numberOfMonths: number,

  /**
   * A React component that display the currently applied date and open the calendar.
   */
  input: element,

  /**
   * The placeholder text.
   */
  placeholder: string,

  /**
   * A format to display a date.
   */
  dateFormat: string,

  /**
   * Whether or not the calendar will open upward.
   */
  upward: bool,

  /**
   * A calendar can open to the left or to the right.
   */
  direction: oneOf(["left", "right"]),

  /**
   * Disables automatic repositioning of the calendar, it will always be placed according to upward and direction values.
   */
  pinned: bool,

  /**
   * z-index of the calendar.
   */
  zIndex: number,

  /**
   * A React component to select a date.
   */
  calendar: element,

  /**
   * A React component displayed under the calendar to `clear` and `apply` the date(s).
   */
  buttons: element,

  /**
   * A controlled open value that determined whether or not the calendar is displayed.
   */
  open: bool,

  /**
   * The initial value of open.
   */
  defaultOpen: bool,

  /**
   * Whether or not to render the calendar element with React portal. The calendar element will be rendered within it's parent DOM hierarchy.
   */
  noPortal: bool,

  /**
   * @ignore
   */
  focus: bool,

  /**
   * @ignore
   */
  className: string
}; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the props will not render properly in the docs.

const SINGLE_DATE_PICKER_DEFAULT_PROPS = {
  allowClear: true,
  dateFormat: "MMM Do YYYY",
  numberOfMonths: 1,
  calendar: /*#__PURE__*/React.createElement(SingleDatePickerCalendar, null),
  buttons: /*#__PURE__*/React.createElement(SingleDatePickerButtons, null)
};
export class InlineSingleDatePicker extends PureComponent {
  // Expose sub-components.
  render() {
    const {
      size,
      ...rest
    } = this.props;

    if (!isNil(size)) {
      throw new Error("".concat(InlineSingleDatePicker.name, " doesn't support the \"size\" prop."));
    }

    return /*#__PURE__*/React.createElement(SingleDatePicker, rest);
  }

}
InlineSingleDatePicker.displayName = "InlineSingleDatePicker";
InlineSingleDatePicker.propTypes = SINGLE_DATE_PICKER_PROP_TYPES;
InlineSingleDatePicker.defaultProps = {
  input: /*#__PURE__*/React.createElement(InlineSingleDatePickerInput, null),
  placeholder: "pick a date",
  ...SINGLE_DATE_PICKER_DEFAULT_PROPS
};
InlineSingleDatePicker.Input = InlineSingleDatePickerInput;
InlineSingleDatePicker.Calendar = SingleDatePickerCalendar;
InlineSingleDatePicker.Buttons = SingleDatePickerButtons;